package cn.com.infosec.asn1.isismtt.x509;

import cn.com.infosec.asn1.ASN1Encodable;
import cn.com.infosec.asn1.ASN1EncodableVector;
import cn.com.infosec.asn1.ASN1Sequence;
import cn.com.infosec.asn1.ASN1TaggedObject;
import cn.com.infosec.asn1.DEREncodable;
import cn.com.infosec.asn1.DERObject;
import cn.com.infosec.asn1.DERSequence;
import cn.com.infosec.asn1.DERTaggedObject;
import cn.com.infosec.asn1.x509.GeneralName;
import java.util.Enumeration;

public class Admissions extends ASN1Encodable {
   private GeneralName admissionAuthority;
   private NamingAuthority namingAuthority;
   private ASN1Sequence professionInfos;

   public static Admissions getInstance(Object obj) {
      if (obj != null && !(obj instanceof Admissions)) {
         if (obj instanceof ASN1Sequence) {
            return new Admissions((ASN1Sequence)obj);
         } else {
            throw new IllegalArgumentException("illegal object in getInstance: " + obj.getClass().getName());
         }
      } else {
         return (Admissions)obj;
      }
   }

   private Admissions(ASN1Sequence seq) {
      if (seq.size() <= 3) {
         DEREncodable var2;
         Enumeration seq1;
         ASN1TaggedObject var5;
         if ((var2 = (DEREncodable)(seq1 = seq.getObjects()).nextElement()) instanceof ASN1TaggedObject) {
            int var3;
            if ((var3 = (var5 = (ASN1TaggedObject)var2).getTagNo()) != 0) {
               if (var3 != 1) {
                  throw new IllegalArgumentException("Bad tag number: " + var5.getTagNo());
               }

               this.namingAuthority = NamingAuthority.getInstance(var5, true);
            } else {
               this.admissionAuthority = GeneralName.getInstance(var5, true);
            }

            var2 = (DEREncodable)seq1.nextElement();
         }

         if (var2 instanceof ASN1TaggedObject) {
            if ((var5 = (ASN1TaggedObject)var2).getTagNo() != 1) {
               throw new IllegalArgumentException("Bad tag number: " + var5.getTagNo());
            }

            this.namingAuthority = NamingAuthority.getInstance(var5, true);
            var2 = (DEREncodable)seq1.nextElement();
         }

         this.professionInfos = ASN1Sequence.getInstance(var2);
         if (seq1.hasMoreElements()) {
            throw new IllegalArgumentException("Bad object encountered: " + seq1.nextElement().getClass());
         }
      } else {
         throw new IllegalArgumentException("Bad sequence size: " + seq.size());
      }
   }

   public Admissions(GeneralName admissionAuthority, NamingAuthority namingAuthority, ProfessionInfo[] professionInfos) {
      Admissions var10000 = this;
      super();
      this.admissionAuthority = admissionAuthority;
      this.namingAuthority = namingAuthority;
      DERSequence var4;
      var4 = new DERSequence.<init>(professionInfos);
      var10000.professionInfos = var4;
   }

   public GeneralName getAdmissionAuthority() {
      return this.admissionAuthority;
   }

   public NamingAuthority getNamingAuthority() {
      return this.namingAuthority;
   }

   public ProfessionInfo[] getProfessionInfos() {
      ProfessionInfo[] var3 = new ProfessionInfo[this.professionInfos.size()];
      int var1 = 0;

      for(Enumeration var2 = this.professionInfos.getObjects(); var2.hasMoreElements(); var3[var1++] = ProfessionInfo.getInstance(var2.nextElement())) {
      }

      return var3;
   }

   public DERObject toASN1Object() {
      ASN1EncodableVector var1;
      var1 = new ASN1EncodableVector.<init>();
      GeneralName var2;
      DERTaggedObject var3;
      if ((var2 = this.admissionAuthority) != null) {
         var3 = new DERTaggedObject.<init>(true, 0, var2);
         var1.add(var3);
      }

      NamingAuthority var4;
      if ((var4 = this.namingAuthority) != null) {
         var3 = new DERTaggedObject.<init>(true, 1, var4);
         var1.add(var3);
      }

      var1.add(this.professionInfos);
      return new DERSequence(var1);
   }
}
